@@ -30,5 +30,5 @@
  * under the License.
  */
 
-require('../setup_node_env/dist');
-require('./cli');
\ No newline at end of file
+require("../setup_node_env/dist");
+require("./cli");
\ No newline at end of file
